ConnectChannelRequest

Trait ConnectChannelRequest 

pub trait ConnectChannelRequest: Serialize {
    type Incoming: DeserializeOwned + 'static;
    type Outgoing: Serialize + 'static;

    const NAME: &'static str;
}
Request to connect to the channel.

It’s similar to Request but for connecting to a channel.

Required Associated Constants

const NAME: &'static str

The name of the channel to be connected by this request.

Required Associated Types

type Incoming: DeserializeOwned + 'static

Type of the data we receive from the channel.

type Outgoing: Serialize + 'static

Type of the data we send to the channel.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<R> ConnectChannelRequest for &R

Source

impl<R> ConnectChannelRequest for &mut R

Source

impl<R> ConnectChannelRequest for Box<R>

Implementors