pub trait ConnectChannelRequest: Serialize {
type Incoming: DeserializeOwned + 'static;
type Outgoing: Serialize + 'static;
const NAME: &'static str;
}Expand description
Request to connect to the channel.
It’s similar to Request but for connecting to a channel.
Required Associated Constants
Required Associated Types
Sourcetype Incoming: DeserializeOwned + 'static
type Incoming: DeserializeOwned + 'static
Type of the data we receive from the channel.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.